Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(893)

Unified Diff: content/public/android/java/src/org/chromium/content/browser/SelectionClient.java

Issue 2863573004: Explicitly tell Smart Select whether or not to suggest (Closed)
Patch Set: Make cancel requests explicit Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/android/java/src/org/chromium/content/browser/SelectionClient.java
diff --git a/content/public/android/java/src/org/chromium/content/browser/SelectionClient.java b/content/public/android/java/src/org/chromium/content/browser/SelectionClient.java
index 7c9a844914f480ab7af0c7bab822fedf82dbb7e1..d699319b3371ea1febc4f70a5837b6000d9b197c 100644
--- a/content/public/android/java/src/org/chromium/content/browser/SelectionClient.java
+++ b/content/public/android/java/src/org/chromium/content/browser/SelectionClient.java
@@ -30,9 +30,16 @@ public interface SelectionClient {
void showUnhandledTapUIIfNeeded(int x, int y);
/**
* Returns true if the SelectionClient sends responces that can contain information about
* the context menu (e.g. that we need a new menu item). In this case an embedder might want
* to wait for this responce before taking further actions.
Donn Denman 2017/05/05 01:23:24 Nit: use @return here.
amaralp 2017/05/05 21:18:31 Done.
*/
- boolean sendsSelectionPopupUpdates();
+ boolean requestSelectionPopupUpdates(boolean shouldSuggest);
+
+ /**
+ * Cancel any outstanding requests the embedder had previously requested using
+ * SelectionClient.requestSelectionPopupUpdates().
+ */
+ public void cancelAllRequests();
}

Powered by Google App Engine
@@ -30,9 +30,16 @@ public interface SelectionClient {
void showUnhandledTapUIIfNeeded(int x, int y);
/**
- * Returns true if the SelectionClient sends responces that can contain information about
- * the context menu (e.g. that we need a new menu item). In this case an embedder might want
- * to wait for this responce before taking further actions.
+ * Notifies the SelectionClient that the selection menu has been requested. It returns true if
+ * the embedder should wait for a response before showing the selection menu. The response can
+ * contain information about the selection menu (e.g. that we need a new menu item).
+ * @param shouldSuggest Whether SelectionClient should suggest and classify or just classify.
Donn Denman 2017/05/05 01:23:24 Nit: use @return here.
amaralp 2017/05/05 21:18:31 Done.
This is Rietveld 408576698